@@ -120,7 +120,7 @@ static void hard_link_one(int i)
 	} else {
 		if (st2.st_dev == st1.st_dev && st2.st_ino == st1.st_ino) return;
 		
-		if (do_unlink(f_name(&hlink_list[i])) != 0 ||
+		if (robust_unlink(f_name(&hlink_list[i])) != 0 ||
 		    do_link(f_name(&hlink_list[i-1]),f_name(&hlink_list[i])) != 0) {
 			if (verbose > 0)
 				rprintf(FINFO,"link %s => %s : %s\n",
